function [ raiz, n ] = cpc_bissecao( _fx, _xl, _xu, _es );
// Metodo da bisseção
//
// Calling Sequence
// fun = 'log(x) + x';
// [ raiz, n ] = cpc_bissecao( fun, 0.1, 2, 0.1 );
//
// Parameters
// raiz : função em x
// n : numero de iterações realizadas para chegar no erro especificado
// _fun : raiz procurada
// _xl : limite inferior do intervalo de busca
// _xu : limite superior do intervalo de busca
// _es : critério de parada que é opcional
//
// Description
// Método de busca de raízes que bissecta repetidamente um intervalo e então seleciona um subintervalo contendo a raiz para processamento adicional.
//
// Examples
// [ raiz, n ] = cpc_bissecao( fun, 0.1, 2, 0.1 );
//
// Authors
// Copyright (C) 2017 - Jonas Vieira de Souza
//
// See Also
//
// Bibliograph
//
    x = _xu;
    fu = evstr( _fx );    
    x = _xl;
    fl = evstr( _fx );    
    if fu*fl > 0 then
        raiz = "Não há Raizes no intervalo fornecido";
        n = 0;
    else
        if argn(2) < 4 then
            _es = 0.0001;
        end   
        ea = 100;
        xr_novo = _xl;
        n=0;
        printf("Iteração\tErro\n");
        while ea > _es do
            xr_velho = xr_novo;
            xr_novo = ( _xl + _xu )/2;
            if xr_novo ~= 0 then
                ea = abs((xr_novo - xr_velho)/xr_novo)*100;
            end
            printf("%d\t\t%f\n",n,ea);        
            x = xr_novo;
            fr = evstr( _fx );        
            x = _xl;
            fl = evstr( _fx );        
            if fl*fr > 0 then
                _xl = xr_novo;
            else
                _xu = xr_novo;
            end        
            n = n + 1;
        end // fim while
        raiz = xr_novo;
    end
endfunction
