function x = cpc_cholesky( A, b )
// Método de Cholesky
//
// Calling Sequence
// coefs = '[ 6 15 55; 15 55 225; 55 225 979 ]';
// ests  = '[ 76; 295; 1259 ]';
// x = cpc_cholesky( coefs, ests );
//
// Parameters
// x : retorno vazio
// _a : função de entrada literal em x e n
// _b : numero do termo
//
// Description
// Permite obter de forma matricial da ortonormalização de Gram-Schimdt
//
// Examples
// x = cpc_cholesky( coefs, ests );
//
// Authors
// Copyright (C) 2017 - Jonas Vieira de Souza
//
// See Also
//
// Bibliograph
//
    [linha,coluna] = size(A);    // se obtem o tamanho da matriz A
    [lB,cB] = size(b);           // tamanho da matriz b
    if linha~=coluna then
        error('A Matriz deve ser quadrada');
    end
    if lB~=linha then
        error('A Matriz b deve ter o mesmo numero de linhas de A');
    end
    if cB~=1 then
        error('A Matriz b deve conter apenas 1 coluna');
    end
    Ut = zeros(linha,coluna);
    d = zeros(linha,1);
    x = zeros(linha,1);
    // Substituição progressiva
    for i=1:linha
        for j=1:coluna
            somatorio = 0;
            if i==j then
                for k=1:i-1
                    somatorio = somatorio + U(k,i)^2;
                end
                U(i,i) = sqrt(A(i,i)-somatorio);
                Ut(i,i) = U(i,i);
            elseif j>i then
                for k=1:i-1
                    somatorio = somatorio + U(k,i)*U(k,j);
                end
                U(i,j) = (A(i,j)-somatorio)/U(i,i);
                Ut(j,i) = U(i,j);
            end
        end
    end
    // [Ut]*{x}={d}
    for i=1:linha
        for j=1:coluna
            if i==j then
                d(i,1) = (b(i,1) - d(i,1))/Ut(i,i);
            elseif i>j then
                d(i,1) = d(i,1) + d(j,1)*Ut(i,j);
            end
        end
    end
    // Substituição Regressiva
    // [U]*[x] = {d}
    for i=linha:-1:1
        for j=coluna:-1:1
            if i==j then
                x(i,1) = (d(i,1)-x(i,1))/U(i,j);
            elseif i<j then
                x(i,1) = x(i,1) + x(j,1)*U(i,j);
            end
        end
    end
endfunction
