function x = cpc_fatoracao_LU( _a, _b )
// Fatoração LU
//
// Calling Sequence
// coefs = [ 10 2 -1; -3 -5 2; 1 1 6 ];
// ests = [ 27; -61.5; -21.5 ]
// vet_sol = cpc_fatoracao_LU( coefs, ests );
//
// Parameters
// vet_sol : resultado
// _a : matriz de coeficientes
// _b : vetor de estímulos (vetor coluna)
//
// Description
// É uma forma de fatoração de uma matriz não singular como o produto de uma matriz triangular inferior (lower) e uma matriz triangular superior (upper).
//
// Examples
// vet_sol = cpc_fatoracao_LU( coefs, ests );
//
// Authors
// Copyright (C) 2017 - Jonas Vieira de Souza
//
// See Also
//
// Bibliograph
//
    //checando os dados de entrada (matriz deve ser quadrada)
    [ l_a, c_a ] = size(_a);
    if l_a ~= c_a then
        error("A Matriz de coeficientes deve ser quadrada");
    end
    [ l_b, c_b ] = size(_b);
    if l_a ~= l_b then
        error("O vetor de estimulos(Resultados) deve ser da ordem da matriz")
    end
    P = eye( c_a, c_a );
    // Eliminação Progressiva
    for i = 1:c_a-1           //Varredura iniciando pelo primeiro pivo (Varre as Colunas)
        //Pivotamento Parcial
        [maior,k]=max(abs(_a(i:c_a,i))); //maior é o numero... k é o indice
        l = i + (k-1);                  //Ajusta o indice ao novo tamanho da matriz
        if l~=i then                    //Se o maior naum estiver na linha de analise troca
            _a([l,i],:) = _a([i,l],:);    //Troca uma linha por outra
            P([l,i],:) = P([i,l],:);    //Troca uma linha por outra
        end
        for j = i+1:c_a       //Varredura para diagonalizar a partir do pivo
            temp = _a(j,i)/_a(i,i); //Calculo do L21, L31....
            _a(j,i:c_a) = _a(j,i:c_a) - temp*_a(i,i:c_a);
            _a(j,i) = temp;
        end
    end
    disp(_a,'U');
    disp(P,'P');
    //Substituição Progressiva
    _b = P*_b;
    d(1) = _b(1);
    for i = 2:c_a
        d(i) = _b(i) - (_a(i,1:(i-1))*d(1:(i-1)));
    end
    disp(d,'d')
    //Substituição Regressiva
    x = zeros(c_a,1);
    x(c_a) = d(c_a)/_a(c_a,c_a);
    for i = c_a-1:-1:1
        // resolvendo com 'for' implicito'
        x(i) = (d(i)-_a(i,(i+1):c_a)*x((i+1):c_a))/_a(i,i);
    end
endfunction
