function x = cpc_gauss_ingenua( _a, _b)
// Eliminação de Gauss Ingênua
//
// Calling Sequence
// coefs = [ 10 2 -1; -3 -5 2; 1 1 6 ];
// ests = [ 27; -61.5; -21.5 ]
// vet_sol = cpc_gaussi_ingenua( coefs, ests );
//
// Parameters
// vet_sol : resultado
// _a : matriz de coeficientes
// _b : vetor de estímulos (vetor coluna)
//
// Description
// É um algoritmo para se resolver sistemas de equações lineares.
//
// Examples
// vet_sol = cpc_gaussi_ingenua( coefs, ests );
//
// Authors
// Copyright (C) 2017 - Jonas Vieira de Souza
//
// See Also
//
// Bibliograph
//
    [l_a,c_a] = size(_a);
    if lA ~= cA then
        error("A matriz A deve ser quadrada");
    end
    [l_b, c_b] = size(_b);
    if l_a ~= l_b then
        error("A matriz b deve conter o mesmo numero de linhas de A");
    end
    for i = 1, l_a
        for j = 1, c_a
             if _a(i,j) == 0 then
                error("A matriz A possui coeficiente nulo!\n");
             end
        end
    end
    for i = 1, l_b
        if _a(i,1) == 0 then
            error("A matriz A possui coeficiente nulo!\n");
        end
    end

    nb = c_a + 1;
    AB = [_a _b];

    for i = 1:c_a-1
        for j = i+1:c_a
            pivo = AB(j,i)/AB(i,i);
            AB(j,1:nb) = AB(j,1:nb) - AB(i,1:nb)*pivo;
        end
    end
    disp(AB);       // Verifica se a eliminação progressiva funcionou
    x = 0;          // Retorno da função
endfunction
