function x = cpc_gauss_pivotamento( _a, _b )
// Eliminação de Gauss com Pivotamento
//
// Calling Sequence
// coefs = [ 0 2 -1; -3 -5 2; 1 1 6 ];
// ests = [ 27; -61.5; -21.5 ]
// vet_sol = cpc_gauss_pivotamento( coefs, ests );
//
// Parameters
// vet_sol : resultado
// _a : matriz de coeficientes
// _b : vetor de estímulos (vetor coluna)
//
// Description
// É um algoritmo para se resolver sistemas de equações lineares.
//
// Examples
// vet_sol = cpc_gauss_pivotamento( coefs, ests );
//
// Authors
// Copyright (C) 2017 - Jonas Vieira de Souza
//
// See Also
//
// Bibliograph
//
    [l_a, c_a] = size(_a);    // se obtem o tamanho da matriz A
    [l_b, c_b] = size(_b);  // tamanho da matriz b
    if l_a ~= c_a then
        error('A Matriz deve ser quadrada'); 
    end
    if l_b ~= l_a then
        error('A Matriz b deve ter o mesmo numero de linhas de A');
    end
    if c_b ~= 1 then
        error('A Matriz b deve conter apenas 1 coluna');
    end
    nb = c_a + 1;
    Ab = [_a _b];         // Ab acrescenta coluna b no final de A
    // Eliminação Progressiva-
    for k = 1:c_a-1
        // pivotamento parcial
        if Ab(k,k) == 0 then
           y = zeros(1,nb);         // Cria uma matriz linha com nb colunas
           for w = 1:nb
               y(1,w) = Ab(k+1,w);  // salva em y a linhas k+1
               Ab(k+1,w) = Ab(k,w); // substitui na linha k+1 a linha k
               Ab(k,w) = y(1,w);    // substitui y na linha k
           end
        end
        for i = k+1:c_a
            PIVO = Ab(i,k)/Ab(k,k);                 // ex:mult = a21/a11
            Ab(i,k:nb) = Ab(i,k:nb)-PIVO*Ab(k,k:nb);// ex:Ab(2,1)=Ab(2,1)-mult*(1,1)
        end
    end
    // Substituição regressiva
    x = zeros(c_a,1);         // Cria uma matriz (n,1) com valores zero
    x(c_a) = Ab(c_a,nb)/Ab(c_a,c_a);
    for i = c_a-1:-1:1
        //for implicito para o somatório
        x(i) = (Ab(i,nb)-Ab(i,i+1:c_a)*x(i+1:c_a))/Ab(i,i);
    end
    disp(Ab);
endfunction
