function [ vet_sol, n_int ] = cpc_gauss_seidel( _a, _b, _rel, _es, _max )
// Método de Gauss Seidel
//
// Calling Sequence
// coefs = [ 7 -1; -1 5 ];
// ests  = [ 3; 2 ];
// rel   = 1.3;
// es = 0.001;
// _max = 50;
// [ vet_sol, n_int ] = cpc_gauss_seidel( coefs, ests, rel, es, _max );
//
// Parameters
// vet_sol  : vetor solução
// n_int    : numero de iterações
// _a       : matriz de coeficientes do sistema
// _b       : vetor coluna dos estimulos (resultados do sistema)
// _rel     : fator de relaxamento
// _es      : critério de parada
// _max     : número máximo de iterações
//
// Description
// É um método iterativo para resolução de sistemas de equações lineares
//
// Examples
// [ vet_sol, n_int ] = cpc_gauss_seidel( coefs, ests, rel, es, _max );
//
// Authors
// Copyright (C) 2017 - Jonas Vieira de Souza
//
// See Also
//
// Bibliograph
//
    if argn(2) < 5 then
        _max = 50;
        if argn(2) < 4 then
            _es = 0.00001;
            if argn(2) < 3 then
                _rel = 1;
            end
        end
    end
    [ l_a, c_a ] = size(_a);
    if l_a ~= c_a then
        error("A Matriz de coeficientes deve ser quadrada");
    end
    [ l_b, c_b ] = size(_b);
    if l_b ~= l_a then
        error("O vetor de estimulos(Resultados) deve ser da ordem da matriz")
    end
    //gerando a matriz 'd' (vai ser a matriz 'b' modificada) e 'C' (vai ser a matriz 'A' modificada)
    for i = 1:c_a
        for j = 1:c_a
            if i==j then
                _b(i) = _b(i)/_a(i,i);
                x(i) = 0
            else
                _a(i,j) = _a(i,j)/_a(i,i);
            end
        end
        _a(i,i) = 0;
    end
    disp( _b,'b' );
    disp( _a,'A' );
    ea = 100;
    n_int =0;
    while (1) do
        for i = 1:c_a
            x_old = x(i);
            x(i) = _b(i) - _a(i,:)*x(:);            
            x(i) = _rel*x(i) + (1-_rel)*x_old;      //Correção do relaxamento 
            ea(i) = abs((x(i) - x_old)/x(i))*100;   //Calculo do erro abs
        end        
        n_int = n_int + 1;        
        if (max(ea) <= _es | n_int == _max ) then
            break;
        end
    end
    vet_sol = x;
endfunction
