function [ vet_sol, n_int ] = cpc_newton_raphson( _fx, _jac, _es, _max )
// Newton-Raphson
//
// Calling Sequence
// fun = ['x(2) + (x(1))^2 - x(1) - 0.5';' x(2) + 5*x(1)*x(2) - (x(1))^2'];
// jac = ['(2*x(1)) - 1' '1';'5*x(2) - 2*(x(1))' ' 1 + 5*x(1)'];
// [ vet_sol, n_int ] = cpc_newton_raphson( fun, jac );
//
// Parameters
// vet_sol  : vetor solução
// n_int    : numero de iterações realizadas para chegar no erro especificado
// _fx      : raiz procurada
// _jac     : matriz jacobiana literal em (x) do sistema
// _es      : critério de parada que é opcional
// _max     : numero máximo de iterações que é opcional
//
// Description
// Resolução de Sistemas Não Lineares por Newton-Raphson
//
// Examples
// [ vet_sol, n_int ] = cpc_newton_raphson( fun, jac );
//
// Authors
// Copyright (C) 2017 - Jonas Vieira de Souza
//
// See Also
//
// Bibliograph
//
    if argn(2) < 3 then    // Se es não for estabelecido usar padrão
        _es = 0.0001;
    end    
    if argn(2) < 4 then    // Se maxi não for estabelecido
        _max = 50;
    end
    x0 = input("Entre com o vetor coluna de aprox. iniciais: ");
    x  = x0;
    ea = 100;
    i = 0;
    while ea > _es & i < _max do
        J = evstr( _jac );
        f = evstr( _fx  );
        //y = J\f;
        xi = x - J\f;
        i = i + 1;
        if x ~= 0 then
            ea = max(abs((xi-x)/xi))*100;
        end
        x = xi;
    end
    if i == _max then
        disp('divergiu');
    else
        disp('convergiu');
    end
    n_int = i;
endfunction
