function [ raiz, n_int ] = cpc_ponto_fixo( _fx, _apx, _max, _es )
// Ponto Fixo
//
// Calling Sequence
// fun = 'sin(sqrt(x))'
// [ raiz, n_int ] = cpc_ponto_fixo( fun, 0.1, 2, 1 );
//
// Parameters
// raiz     : raiz procurada
// n_int    : número de interações realizadas
// _fx      : função de entrada literal em x e n
// _apx     : valor inicial de aproximação
// _max     : numero do termo
// _es      : critério de parada
//
// Description
// Ponto Fixo
//
// Examples
// [ raiz, n_int ] = cpc_ponto_fixo( fun, 0.1, 2, 1 );
//
// Authors
// Copyright (C) 2017 - Jonas Vieira de Souza
//
// See Also
//
// Bibliograph
//
    if argn(2) < 4 then
        _max = 100;
        if argn(2) < 3 then
            _es = 0.01;
        end
    end
    ea = 100;
    n_int = 0;
    x = _apx;
    printf("\nInt\tXi\t\t|Ea|%%\n");
    while ( ea > _es ) & ( n_int < _max ) do
        xi = evstr(_fx);
        if ( xi ~= 0 ) then
            ea = abs((xi - x)/xi)*100;
        end
        printf("%d\t%f\t%f\n", n_int, xi, ea);
        x = xi;
        n_int = n_int + 1;
    end
    if n_int >= _max then
        raiz = "ERRO -> divergiu";
    else
        raiz = xi;
    end
endfunction
