function [ c, g ] = cpc_regressao_linear( _x, _y )
// Regressão linear
//
// Calling Sequence
// x [];
// y [];
// [ c, g ] = cpc_regressao_linear( x, y );
//
// Parameters
// c    : coeficientes da equação da curva
// g    : grau de certeza da curva em relação aos pontos
// _x   : vetor de pontos do eixo x
// _y   : vetor de pontos do eixo y
//
// Description
// Função para ajuste de curvas por regressão linear
//
// Examples
// [ c, g ] = cpc_regressao_linear( x, y );
//
// Authors
// Copyright (C) 2017 - Jonas Vieira de Souza
//
// See Also
//
// Bibliograph
//
    n = length(_x);
    if(n~=length(_y))
        error("Dados inconsistentes, x e y devem ter o mesmo tamanho");
    end
    plot(_x,_y,'+');xgrid;
    disp('Digite');
    disp('<1> para ajuste por uma reta');
    disp('<2> para ajuste por uma exponencial');
    disp('<3> para ajuste por uma potencia simples');
    disp('<4> para ajuste por uma taxa de crescimento saturada');
    op = input(' --> ');
    if op == 4 then
        disp('Entre com a ordem do modelo');
        m = input(' --> ');
    end
    xa = linspace(min(_x),max(_x),100);
    // Transformação das variáveis
    if op == 2 then
        _y = log(_y);
    elseif op == 3 then
        _x = log10(_x);
        _y = log10(_y);
    elseif op == 4 then
        _x = 1 ./_x .^m;
        _y = 1 ./_y;
    end
    somax = sum(_x);
    somay = sum(_y);
    somaxy = sum(_x.*_y);
    somaxx = sum(_x.^2);
    somayy = sum(_y.^2);
    A = n*somaxy -somax*somay;
    B = n*somaxx -somax^2;
    C = n*somayy -somay^2;
    c(2) = A/B;
    c(1) = somay/n -c(2)*somax/n;
    g = (A/(sqrt(B)*sqrt(C)))^2;
    if op==1 then
        ya = c(1) +c(2)*xa;
    elseif op == 2 then
        alfa = exp(c(1));
        betha = c(2);
        ya = alfa*exp(betha*xa);
    elseif op == 3 then
        alfa = 10^c(1);
        betha = c(2);
        ya = alfa*xa^betha;
    elseif op == 4 then
        alfa = 1/c(1);
        betha = (alfa*c(2))^(1/m);
        ya = (alfa*xa.^m) ./(betha.^m +xa.^m);
    end
    plot(xa,ya);
    xgrid;
endfunction
