function [ vet_sol, v_indep ] = cpc_rk4( _fx, _ti, _tf, _h, _ciy )
// Resolução de sistemas de EDOs por RK4
//
// Calling Sequence
// fun = '[ya(2), 9.8 - (0.25/68.1)*ya(2)^2]';
// [ vet_sol, v_indep ] = cpc_rk4( fun, 0, 10, 1, [0,0] );
//
// Parameters
//  vet_sol  : vetor solução da variável dependente
//  v_indep  : valor da variável independente
//  _fx      : raiz procurada
//  _ti      : instante inicial
//  _h       : tamanho do passo
//  _ciy     : condições iniciais de y
//
// Description
// Resolução de sistemas de EDOs por RK4
//
// Examples
// [ vet_sol, v_indep ] = cpc_rk4( fun, 0, 10, 1, [0,0] );
//
// Authors
// Copyright (C) 2017 - Jonas Vieira de Souza
//
// See Also
//
// Bibliograph
//
      v_indep(1) = _ti;     // base de tempo
    vet_sol(1,:) = _ciy;    // condições iniciais
               i = 1;       // iterador
              ta = _ti;     // t de avaliação
    while ta < _tf do
         ya = vet_sol(i,:);
         k1 = evstr( _fx );
         ya = vet_sol(i,:) +k1*_h/2;
         ta = ta +_h/2;
         k2 = evstr( _fx );
         ya = vet_sol(i,:) +k2*_h/2;
         k3 = evstr( _fx );
         ya = vet_sol(i,:) +k3*_h;
         ta = ta + _h/2;
         k4 = evstr( _fx );
         phi = k1 +2*k2 +2*k3 +k4;
         vet_sol(i+1,:) = vet_sol(i,:) +phi*_h/6;
         v_indep(i+1) = ta;
         i = i +1;
     end
endfunction
