function [ raiz, n_int ] = cpc_secante_modificada( _fx, _x0, _es, _dx, _max )
// Secante Modificada
//
// Calling Sequence
// fun = 'log(x) +x';
// [ raiz, n_int ] = cpc_secante_modificada( fx, 0.1 )
//
// Parameters
// raiz     : raiz procurada
// n_int    : número de interações realizadas
// _fx      : função de entrada literal em x
// _xo      : condição inicial
// _es      : criterio de parada
// _dx      : perturbação na condição inicial
// _max     : número máximo de iteração
//
// Description
// Trata-se do caso mais simples de Fórmula de Newton-Cotes fechada
//
// Examples
// [ raiz, n_int ] = cpc_secante_modificada( fx, 0.1 );
//
// Authors
// Copyright (C) 2017 - Jonas Vieira de Souza
//
// See Also
//
// Bibliograph
//
    if argn(2) < 3 then
        _es = 0.0001;
    end
    if argn(2) < 4 then
        _dx = 0.01;
    end
    if argn(2) < 5 then
        _max = 50;
    end
    n_int = 0;                 // Numero de iterações
    erroa = 100;           // Erro absoluto
    x = _x0;
    printf("Iter\txi\t\tErroa\n");
    while erroa > _es & n_int < _max do
        f1 = evstr(_fx);
        temp = x;
        x = x*_dx + x;
        f2 = evstr(_fx);
        x = temp;
        xi = x - (f1*_dx*x/(f2 - f1));
        n_int = n_int + 1;
        if xi ~= 0 then
            erroa = abs((xi-x)/xi)*100;
        end
        disp(xi);
        printf("%d\t%f\t%f\n", n_int, xi, erroa);
        x = xi;
    end
    if n_int == _max then
        raiz = 'divergiu';
    else
        raiz = xi;
    end
endfunction
