function [ fx, term ] = cpc_serie_pot( fun, fun_r, x, n_sig )
// Série de potências
//
// Calling Sequence
// fun ='x^n/factorial(n)';
// [ fx, term ] = cpc_series( fun, fun_r, 5, 3 );
//
// Parameters
// fx       : função em x
// term     : número de termos usados para o erro especificado
// _fun     : função de entrada literal em x e n
// _n       : numero do termo
// _n_sig   : numero de alg. sign. da resposta - opcional
//
// Description
// Trata-se do caso mais simples de Fórmula de Newton-Cotes fechada
//
// Examples
// [ fx, term ] = cpc_series( fun, fun_r, 5, 3 );
//
// Authors
// Copyright (C) 2017 - Jonas Vieira de Souza
//
// See Also
//
// Bibliograph
//
    if argn(2) < 4 then         // argn(2) retorna o no de args de entrada
        n_sig = 3;
    end
    es = 0.005*10^(2-n_sig);    // criterio relativo de parada
    fx = 0;                     // zera inicio
    fx_old = 0;                 // zera o antigo
    n = 0;                      // numero de termos
    v_r = evstr(fun_r);         // valor real para calcular erro
    printf("Termo\t\tfx\t\tet %%\t\tea %%\n"); // imprime cabeçalho
    while 1 do
        fx = fx + evstr(fun);
        erro = abs((fx - fx_old)/fx);
        e_real = abs((v_r - fx)/v_r);
        printf("%f\t%f\t%f\t%f\n", n+1, fx, e_real*100, erro*100);
        if (erro < es) then
            break;
        end
        fx_old = fx;
        n = n + 1;
    end
    term = n + 1;
    disp(fx,   "resultado da função" );
    disp(term, "quantidade de termos" );
endfunction
