function res = cpc_simpson_13( _fx, _li, _ls, _np )
// Simpson 1/3
//
// Calling Sequence
// fx = '0.2+25*x-200*x.^2+675*x.^3-900*x.^4+400*x.^5';
// res = cpc_simpson_13( fx, 0, 0.8, 4 );
//
// Parameters
// res : resultado
// _fx : função a ser integrada
// _li : limite inferior de integração
// _ls : limite superior de integração
// _np : número de pontos [n+1], ou número do intervalos[n]
//
// Description
// Trata-se do caso mais simples de Fórmula de Newton-Cotes fechada
//
// Examples
// res = cpc_simpson_13( fx, 0, 0.8, 4 );
//
// Authors
// Copyright (C) 2017 - Jonas Vieira de Souza
//
// See Also
//
// Bibliograph
//
    if modulo( _np, 2 ) ~= 0 then
        error("o numero de intervalos nao pode ser impar");
    end   
    x = linspace( _li, _ls, _np+1 );
    f = evstr( _fx );
    disp(f);
    soma1 = 0 ;
    soma2 = 0 ;
    for i=2:2:_np
        soma1 = soma1 + f(i);
    end
    for i=3:2:_np-1
        soma2 = soma2 + f(i);
    end
   int_trap  = ( _ls - _li ) * ( f(1) + 4*soma1 + 2*soma2 + f(_np+1) ) / ( 3 * _np ) ;
endfunction
